==> cirru-writer-0.3.7.tgz: package/lib/transformer.js <==
"use strict";

var bind = function bind(v, k) {
  return k(v);
},
    commaList = [","],
    isString = function isString(x) {
  return typeof(x) === "string";
},
    upHeadComma = function upHeadComma(tree) {
  var head = tree[0];
  return isString(head) ? tree.slice(0, 1) : [transformComma([], [], head, true)];
},
    transformComma = function transformComma(acc, buffer, tree, isLastInline) {
  undefined;
  return tree.length === 0 ? buffer.length === 0 ? acc : acc.concat([commaList.concat(buffer)]) : acc.length === 0 ? transformComma(acc.concat(upHeadComma(tree)), buffer, tree.slice(1), true) : bind(isString(tree[0]), function (isThisInline) {
    return function () {
      switch (true) {
        case isLastInline && isThisInline:
          return buffer.length === 0 ? transformComma(acc.concat(upHeadComma(tree)), [], tree.slice(1), true) : transformComma(acc, buffer.concat(upHeadComma(tree)), tree.slice(1), true);

        case !isLastInline && isThisInline:
          return transformComma(acc, buffer.concat(upHeadComma(tree)), tree.slice(1), true);

        case isLastInline && !isThisInline:
          return buffer.length === 0 ? transformComma(acc.concat(upHeadComma(tree)), [], tree.slice(1), false) : transformComma(acc.concat([commaList.concat(buffer)], upHeadComma(tree)), [], tree.slice(1), false);

        default:
          return transformComma(acc.concat(upHeadComma(tree)), [], tree.slice(1), false);
      }
    }();
  });
},
    insertComma = function insertComma(tree) {
  return tree.map(function (line) {
    return transformComma([], [], line, true);
  });
},
    upDollar = function upDollar(head) {
  return isString(head) ? head : transformDollar([], head, true, 0);
},
    transformDollar = function transformDollar(acc, tree, isLastInline, index) {
  return function () {
    switch (tree.length) {
      case 0:
        return acc;

      case 1:
        return bind(tree[0], function (head) {
          return isLastInline && index > 0 && Array.isArray(head) ? acc.concat("$", upDollar(head)) : acc.concat([upDollar(head)]);
        });

      default:
        return transformDollar(acc.concat([upDollar(tree[0])]), tree.slice(1), isString(tree[0]), index + 1);
    }
  }();
},
    insertDollar = function insertDollar(tree) {
  return tree.map(function (line) {
    return transformDollar([], line, true, 0);
  });
};

exports.insertComma = insertComma;
exports.insertDollar = insertDollar;

==> cirru-writer-0.3.11.tgz: package/lib/transformer.js <==
"use strict";

var bind = function bind(v, k) {
  return k(v);
},
    commaList = [","],
    isString = function isString(x) {
  return typeof(x) === "string";
},
    upHeadComma = function upHeadComma(tree) {
  var head = tree[0];
  return isString(head) ? tree.slice(0, 1) : [transformComma([], [], head, true)];
},
    transformComma = function transformComma(acc, buffer, tree, isLastInline) {
  undefined;
  return tree.length === 0 ? buffer.length === 0 ? acc : acc.concat([commaList.concat(buffer)]) : acc.length === 0 ? transformComma(acc.concat(upHeadComma(tree)), buffer, tree.slice(1), true) : bind(isString(tree[0]), function (isThisInline) {
    return function () {
      switch (true) {
        case isLastInline && isThisInline:
          return buffer.length === 0 ? transformComma(acc.concat(upHeadComma(tree)), [], tree.slice(1), true) : transformComma(acc, buffer.concat(upHeadComma(tree)), tree.slice(1), true);

        case !isLastInline && isThisInline:
          return transformComma(acc, buffer.concat(upHeadComma(tree)), tree.slice(1), true);

        case isLastInline && !isThisInline:
          return buffer.length === 0 ? transformComma(acc.concat(upHeadComma(tree)), [], tree.slice(1), false) : transformComma(acc.concat([commaList.concat(buffer)], upHeadComma(tree)), [], tree.slice(1), false);

        default:
          return transformComma(acc.concat(upHeadComma(tree)), [], tree.slice(1), false);
      }
    }();
  });
},
    insertComma = function insertComma(tree) {
  return tree.map(function (line) {
    return transformComma([], [], line, true);
  });
},
    upDollar = function upDollar(head, usingDollar) {
  return isString(head) ? head : transformDollar([], head, true, 0, usingDollar);
},
    transformDollar = function transformDollar(acc, tree, isLastInline, index, usingDollar) {
  return function () {
    switch (tree.length) {
      case 0:
        return acc;

      case 1:
        return bind(tree[0], function (head) {
          return isLastInline && index > 0 && Array.isArray(head) && !usingDollar ? acc.concat("$", upDollar(head, true)) : acc.concat([upDollar(head, false)]);
        });

      default:
        return transformDollar(acc.concat([upDollar(tree[0], false)]), tree.slice(1), isString(tree[0]), index + 1, usingDollar);
    }
  }();
},
    insertDollar = function insertDollar(tree) {
  return tree.map(function (line) {
    return transformDollar([], line, true, 0, false);
  });
};

exports.insertComma = insertComma;
exports.insertDollar = insertDollar;
